﻿using Borepin.Service;
using Prism.Mvvm;
using Prism.Navigation;
using System;
using System.Threading.Tasks;
using System.Windows.Input;
using Xamarin.Forms;

namespace Borepin.PageModel
{
    public class LoginPasswordPageModel : BindableBase
    {
        private INavigationService _NavigationService;
        private BFFHService _BFFHService;

        private string _KnownUsername;

        public LoginPasswordPageModel(INavigationService navigationService, BFFHService bffhService)
        {
            _NavigationService = navigationService;
            _BFFHService = bffhService;

            AuthenticateCommand = new Command(AuthenticateCommandExecuted);

            LoadData();
        }

        private async Task LoadData()
        {
            _KnownUsername = await _BFFHService.GetUsername();

            if (_KnownUsername != null)
            {
                Username = _KnownUsername;
                Password = "********";
            }
        }

        private string _Username;
        public string Username
        {
            get => _Username;
            set => SetProperty(ref _Username, value);
        }

        private string _Password;
        public string Password
        {
            get => _Password;
            set => SetProperty(ref _Password, value);
        }

        private ICommand _AuthenticateCommand;
        public ICommand AuthenticateCommand
        {
            get => _AuthenticateCommand;
            set => SetProperty(ref _AuthenticateCommand, value);
        }

        private async void AuthenticateCommandExecuted()
        {
            if(_KnownUsername == Username)
            {
                await _BFFHService.AuthenticateAsync();
            }
            else
            {
                await _BFFHService.Authenticate(Username, Password);
            }

            var result = await _NavigationService.NavigateAsync("/MainPage/NavigationPage/MachinesPage");

            if (!result.Success)
            {
                System.Diagnostics.Debugger.Break();
            }
        }
    }
}
