﻿using System;
using System.Collections.Generic;
using FabAccessAPI;
using Capnp.Rpc;
using Borepin.Service.Hosts;
using Borepin.Service.Credentials;
using Borepin.Model;
using System.Threading.Tasks;
using System.Collections.ObjectModel;

namespace Borepin.Service
{
    public class BFFHService
    {
        public Uri ConnectedHost;
        private Connection _Connection;
        private HostService _HostService;
        private CredentialsService _CredentialsService;

        public BFFHService()
        {
            _HostService = new HostService();
            _CredentialsService = new CredentialsService();
        }

        public async Task<ObservableCollection<Uri>> GetKnownHostsAsync()
        {
            return await _HostService.GetKnownHostsAsync();
        }

        public void Connect(Uri host)
        {
            if(_Connection != null)
            {
                throw new System.Exception("Still connected");
            }

            var rpcClient = new TcpRpcClient();
            rpcClient.Connect(host.Host, host.Port);

            Connection connection_test = new Connection(rpcClient);

            _HostService.LogHostAsync(host);

            _Connection = connection_test;
            ConnectedHost = host;
        }

        public void Connect()
        {
            if (ConnectedHost == null)
            {
                throw new System.Exception("No Host selected");
            }

            Connect(ConnectedHost);
        }

        public void Disconnect()
        {
            _Connection.RpcClient?.Dispose();
            _Connection = null;
        }

        public async Task<string> GetUsername()
        {
            return await Task.FromResult((await _CredentialsService.GetCredentialsAsync(ConnectedHost)).Username);
        }

        public async Task<bool> AuthenticateAsync()
        {
            HostCredentials credentials = await _CredentialsService.GetCredentialsAsync(ConnectedHost);

            await _Connection.Auth("PLAIN", new Dictionary<string, object> { { "Username", credentials.Username }, { "Password", credentials.Password } });

            return await Task.FromResult(true);
        }

        public async Task<bool> Authenticate(string username, string password)
        {
            await _Connection.Auth("PLAIN", new Dictionary<string, object> { { "Username", username }, { "Password", password } });

            await _CredentialsService.LogCredentialsAsync(new HostCredentials() { Host = ConnectedHost, Username = username, Password = password });

            return await Task.FromResult(true);
        }
    }
}
