﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Essentials;

namespace Borepin.Service.Hosts
{
    public class HostService : IHostService
    {
        public List<Uri> KnownHosts { get; set; }

        public HostService()
        {
            KnownHosts = new List<Uri>();

            LoadKnownHosts();
        }
            
        public Task<ObservableCollection<Uri>> GetKnownHostsAsync()
        {
            return Task.FromResult(new ObservableCollection<Uri>(KnownHosts));
        }

        public Task<bool> LogHostAsync(Uri host)
        {
            if (KnownHosts.Contains(host))
            {
                return Task.FromResult(true);
            }

            KnownHosts.Add(host);
            return SaveKnownHosts();
        }

        public Task<bool> LoadKnownHosts()
        {
            string knownhosts = Preferences.Get("bffh_knownhost", "");

            List<Uri> knownhost_list = new List<Uri>();

            string[] split = knownhosts.Split(',');

            foreach (string host in split)
            {
                if (host == "")
                {
                    continue;
                }

                Uri host_new = new Uri(host);
                knownhost_list.Add(host_new);
            }

            KnownHosts = knownhost_list;

            return Task.FromResult(true);
        }

        public Task<bool> SaveKnownHosts()
        {
            string knownhosts = "";

            foreach(Uri host in KnownHosts)
            {
                knownhosts += "," + host.ToString();
            }
                
            Preferences.Set("knownhosts", knownhosts);

            return Task.FromResult(true);
        }
    }
}
